/* Alert Block */
.sb-alert {
  padding: 1rem;
  margin-bottom: 1rem;
  border: 1px solid transparent;
  border-radius: 0.375rem;
  font-size: 1rem;
  line-height: 1.5;
  max-width: 90%;
  margin: auto;
  margin-bottom: 1rem;
}

.sb-alert-icon {
  display: inline-block;
  margin-right: 0.5rem;
}

.sb-alert-info {
  background-color: color-mix(in srgb, var(--info-color) 15%, white);
  border-color: color-mix(in srgb, var(--info-color) 25%, white);
  color: color-mix(in srgb, var(--info-color) 70%, black);
}

.sb-alert-warning {
  background-color: color-mix(in srgb, var(--warning-color) 15%, white);
  border-color: color-mix(in srgb, var(--warning-color) 25%, white);
  color: color-mix(in srgb, var(--warning-color) 70%, black);
}

.sb-alert-success {
  background-color: color-mix(in srgb, var(--success-color) 15%, white);
  border-color: color-mix(in srgb, var(--success-color) 25%, white);
  color: color-mix(in srgb, var(--success-color) 70%, black);
}

.sb-alert-danger {
  background-color: color-mix(in srgb, var(--error-color) 15%, white);
  border-color: color-mix(in srgb, var(--error-color) 25%, white);
  color: color-mix(in srgb, var(--error-color) 70%, black);
}

.sb-alert-primary {
  background-color: color-mix(in srgb, var(--primary-color) 15%, white);
  border-color: color-mix(in srgb, var(--primary-color) 25%, white);
  color: color-mix(in srgb, var(--primary-color) 70%, black);
}

.sb-alert-secondary {
  background-color: color-mix(in srgb, var(--secondary-color) 15%, white);
  border-color: color-mix(in srgb, var(--secondary-color) 25%, white);
  color: color-mix(in srgb, var(--secondary-color) 70%, black);
}

/* Card Block */
.sb-card {
  position: relative;
  display: flex;
  flex-direction: column;
  min-width: 0;
  max-width: 90%;
  margin: auto;
  word-wrap: break-word;
  background-color: white;
  background-clip: border-box;
  border: 1px solid color-mix(in srgb, var(--neutral-color) 15%, transparent);
  border-radius: 0.375rem;
  transition: all 0.3s ease-in-out;
  box-shadow: 0 0.125rem 0.25rem color-mix(in srgb, black 7.5%, transparent);
}

.sb-card:hover {
  box-shadow: 0 0.5rem 1rem color-mix(in srgb, black 15%, transparent);
  transform: translateY(-2px);
}

.sb-card-header {
  padding: 0.75rem 1rem;
  margin-bottom: 0;
  background-color: color-mix(in srgb, var(--neutral-color) 3%, white);
  border-bottom: 1px solid
    color-mix(in srgb, var(--neutral-color) 15%, transparent);
}

.sb-card-title {
  margin: 0;
  font-size: 1.25rem;
  font-weight: 500;
  color: color-mix(in srgb, var(--neutral-color) 99%, black);
}

.sb-card-body {
  flex: 1 1 auto;
  padding: 1rem;
}

.sb-card-footer {
  padding: 0.75rem 1rem;
  background-color: color-mix(in srgb, var(--neutral-color) 3%, white);
  border-top: 1px solid
    color-mix(in srgb, var(--neutral-color) 33%, transparent);
}
